@@ -4,6 +4,9 @@ import random
 import requests
 from typing import List, Dict, Optional
 
+# Number of random pages to be read from call report API
+PAGE_SCAN_LIMIT = 5
+
 
 class Connection:
     def __init__(self, org_id: int):
@@ -114,11 +117,15 @@ class Connection:
         # Call Report API is Paginated so data is saved in pages, each page will be a get request
 
         first_page = self._get_request("call", params)
+        current_page = first_page.get("page", 1)
+        total_pages = first_page.get("total_pages", 2)
         call_summary = first_page.get("items", [])
+        pages_to_read = random.sample(range(current_page, total_pages), PAGE_SCAN_LIMIT)
 
-        for _ in range(first_page.get("page"), first_page.get("total_pages") + 1):
-            next_page = self._get_request("call", params)
-            call_summary.extend(next_page.get("items", []))
+        for page in pages_to_read:
+            params["page"] = page
+            items = self._get_request("call", params).get("items", [])
+            call_summary.extend(items)
 
         if call_summary:
             if call_quantity and call_quantity < len(call_summary):
